Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8141)

Unified Diff: chrome/common/extensions/update_url_handler.h

Issue 11726002: Move the parsing of 'update_url' & 'options_page' URLs out of Extension. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@url_parse
Patch Set: Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/extensions/update_url_handler.h
diff --git a/chrome/common/extensions/devtools_page_handler.h b/chrome/common/extensions/update_url_handler.h
similarity index 60%
copy from chrome/common/extensions/devtools_page_handler.h
copy to chrome/common/extensions/update_url_handler.h
index 9d947fe686c12b755bcffe4fffee0162b0126566..0162b047e7bbeca733721feda7f2869676e6a7c0 100644
--- a/chrome/common/extensions/devtools_page_handler.h
+++ b/chrome/common/extensions/update_url_handler.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_COMMON_EXTENSIONS_DEVTOOLS_PAGE_HANDLER_H_
-#define CHROME_COMMON_EXTENSIONS_DEVTOOLS_PAGE_HANDLER_H_
+#ifndef CHROME_COMMON_EXTENSIONS_UPDATE_URL_HANDLER_H_
+#define CHROME_COMMON_EXTENSIONS_UPDATE_URL_HANDLER_H_
#include <string>
@@ -14,11 +14,11 @@ namespace extensions {
class Extension;
-// Parses the "devtools_page" manifest key.
-class DevToolsPageHandler : public ManifestHandler {
+// Parses the "update_url" manifest key.
+class UpdateURLHandler : public ManifestHandler {
public:
- DevToolsPageHandler();
- virtual ~DevToolsPageHandler();
+ UpdateURLHandler();
+ virtual ~UpdateURLHandler();
virtual bool Parse(const base::Value* value,
Extension* extension,
@@ -27,4 +27,4 @@ class DevToolsPageHandler : public ManifestHandler {
} // namespace extensions
-#endif // CHROME_COMMON_EXTENSIONS_DEVTOOLS_PAGE_HANDLER_H_
+#endif // CHROME_COMMON_EXTENSIONS_UPDATE_URL_HANDLER_H_

Powered by Google App Engine
This is Rietveld 408576698